import { BasicColumn, FormSchema } from '@/components/Table';
import {uploadApi} from "@/api/sys/upload";

export const columns: BasicColumn[] = [
  {
    title: '知识名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: '文号',
    dataIndex: 'fileType',
    width: 120,
  },
  {
    title: '权属机构',
    dataIndex: 'deptName',
    width: 120,
  },
  {
    title: '创建人',
    dataIndex: 'createBy',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 140,
  },
  {
    title: '更新人',
    dataIndex: 'updateBy',
    width: 120,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '知识名称',
    component: 'Input',
    colProps: { span: 4 },
    labelWidth: 60,
  },
  {
    field: 'fileType',
    label: '文号',
    component: 'Input',
    colProps: { span: 4 },
    labelWidth: 60,
  },
  {
    field: 'createStartDate',
    label: '创建开始时间',
    component: 'DatePicker',
    colProps: { span: 4 },
    labelWidth: 100,
  },
  {
    field: 'createEndDate',
    label: '创建结束时间',
    component: 'DatePicker',
    colProps: { span: 4 },
    labelWidth: 100,
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'name',
    label: '知识名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'remark',
    label: '描述',
    component: 'Input',
    required: true,
  },
  {
    field: 'fileType',
    label: '文号',
    component: 'Input',
    required: true,
  },
  {
    field: 'deptId',
    label: '权属机构',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'file',
    component: 'Upload',
    label: '上传',
    colProps: { lg: 24, md: 24 },
    rules: [{ required: true, message: '请选择上传文件' }],
  },
];

export const importFormSchema: FormSchema[] = [
  {
    field: 'deptId',
    label: '导入至',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'file',
    component: 'Upload',
    label: '上传',
    colProps: { lg: 24, md: 24 },
    rules: [{ required: true, message: '请选择上传文件' }],
  },
  {
    field: 'flag',
    label: '文件重名',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部覆盖', value: '0' },
        { label: '全部放弃', value: '1' },
        { label: '自动重命名', value: '2' },
      ],
    },
    required: true,
  },
];
export const addFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
